@@ -11,8 +11,8 @@ use assert_fs::{
 use makeclean::project::dto::ProjectDto;
 
 use crate::util::{
-    cargo::cargo_init, elm::elm_init, flutter::flutter_init, fs::canonicalized_str, mix::mix_init,
-    npm::npm_init,
+    cargo::cargo_init, elm::elm_init, flutter::flutter_init, fs::canonicalized_str,
+    gradle::gradle_init, mix::mix_init, npm::npm_init,
 };
 
 #[test]
@@ -22,7 +22,7 @@ fn recognizes_projects() -> Result<()> {
         ("Cargo", cargo_init),
         ("Elm", elm_init),
         ("Flutter", flutter_init),
-        // ("Gradle", gradle_init),
+        ("Gradle", gradle_init),
         // ("Maven", maven_init),
         ("Mix", mix_init),
         ("NPM", npm_init),
